@@ -116,20 +116,23 @@ CLI_EXTRA_DOC = r"""
 """
 
 
-def main(fp=sys.stderr):
+def main(fp=sys.stderr, argv=None):
     """
     Paramters (internal use only)
     ---------
     fp  : file-like object for tqdm
+    argv  : list (default: sys.argv[1:])
     """
+    if argv is None:
+        argv = sys.argv[1:]
     try:
-        log = sys.argv.index('--log')
+        log = argv.index('--log')
     except ValueError:
         logLevel = 'INFO'
     else:
-        # sys.argv.pop(log)
-        # logLevel = sys.argv.pop(log)
-        logLevel = sys.argv[log + 1]
+        # argv.pop(log)
+        # logLevel = argv.pop(log)
+        logLevel = argv[log + 1]
     logging.basicConfig(
         level=getattr(logging, logLevel),
         format="%(levelname)s:%(module)s:%(lineno)d:%(message)s")
@@ -161,14 +164,14 @@ Options:
 """ + d.strip('\n') + '\n'
 
     # opts = docopt(d, version=__version__)
-    if any(v in sys.argv for v in ('-v', '--version')):
+    if any(v in argv for v in ('-v', '--version')):
         sys.stdout.write(__version__ + '\n')
         sys.exit(0)
-    elif any(v in sys.argv for v in ('-h', '--help')):
+    elif any(v in argv for v in ('-h', '--help')):
         sys.stdout.write(d + '\n')
         sys.exit(0)
 
-    argv = RE_SHLEX.split(' '.join(["tqdm"] + sys.argv[1:]))
+    argv = RE_SHLEX.split(' '.join(["tqdm"] + argv))
     opts = dict(zip(argv[1::2], argv[2::2]))
 
     log.debug(opts)
